@@ -16,11 +16,13 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,   *
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.               *
  *****************************************************************************/
+#ifndef MAEMO
 
 #include "trayicon.h"
 
 #include <QClipboard>
 #include <QMenu>
+#include <QSettings>
 
 #include "application.h"
 #include "mainwindow.h"
@@ -53,6 +55,13 @@ TrayIcon::TrayIcon(QObject *parent)
     setContextMenu(trayMenu);
     connect(this, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
             SLOT(on_activated(QSystemTrayIcon::ActivationReason)));
+
+    loadSettings();
+}
+
+TrayIcon::~TrayIcon()
+{
+    saveSettings();
 }
 
 void TrayIcon::on_activated(QSystemTrayIcon::ActivationReason reason)
@@ -84,7 +93,21 @@ void TrayIcon::setScanEnabled(bool enabled)
     setToolTip(tr("QStarDict: scanning is %1").arg(enabled ? tr("enabled") : tr("disabled")));
 }
 
+void TrayIcon::saveSettings()
+{
+    QSettings config;
+    config.setValue("TrayIcon/visible", isVisible());
 }
 
+void TrayIcon::loadSettings()
+{
+    QSettings config;
+    setVisible(config.value("TrayIcon/visible", true).toBool());
+}
+
+}
+
+#endif // MAEMO
+
 // vim: tabstop=4 softtabstop=4 shiftwidth=4 expandtab cindent textwidth=120 formatoptions=tc
 
